<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:java="http://xml.apache.org/xslt/java" xmlns:tmx="http://www.lisa.org/tmx14">
  <!-- For character entities: http://www.w3.org/MarkUp/html3/latin1.html -->
  <!-- The necessity for using xml namespaces all over and matching on namespaced element names http://www.stylusstudio.com/xsllist/200302/post70120.html -->

   <!-- HOW AND WHEN TO USE THIS FILE
       1. Generate an xml file containing the chunks requiring work.
       GS2/bin/script> perl -S gti.pl get-first-n-chunks-requiring-work mi coredm 1000 > ../../macros/maori/mi-core.xml

       2. Generate a TMX file from that XML file as follows:
       GS2/bin/script> java -cp /research/ak19/gs2-svn/bin/java/ApplyXSLT.jar org.nzdl.gsdl.ApplyXSLT -x ../../macros/maori/mi-core.xml -t ../script/gti-generate-tmx-xml.xsl -l mi > ../../maori/core-mi.tmx

       3. Apply this XSLT to that XML file to obtain a unicode text file containing tab-separated values (a spreadsheet). 
       NOTE: Make sure the output is a *.txt file if you wish to open it in Excel without losing the unicode 
       (when opened with .csv extension, the unicode is not preserved).

       GS2/bin/script> java -cp /research/ak19/gs2-svn/bin/java/ApplyXSLT.jar org.nzdl.gsdl.ApplyXSLT -x ../../maori/core-mi.tmx -t ../script/gti-tmx-to-spreadsheet.xsl > ../../maori/core-mi-tmx2spreadsheet.txt

       4. Translators wishing to read this text file into Excel, need to first open Excel. 
       Then go to File > Open, set the filetypes drop-down to show All Files *.*,
       and choose to open the unicode .txt file containing the tab-separated values.

       - A wizard will appear, allowing users to open this .txt file as a proper spreadsheet.
       In the first frame of this dialog, need to specify
       a. on the left that the file is "delimited"
       b. in the drop down on the right, select unicode (UTF-8 or UTF-16)
       c. Click next
       In the second frame of the dialog, select "tab" as the delimiter. Click Finish to open the spreadsheet data.
       
       5. When translators have finished working on the file, save it as an Excel spreadsheet Unicode .txt file 
       (through File > Save As > Excel 2003 spreadsheet > choose Unicode .txt in the file types box)
       and mail this text file back to Greenstone.

       6. The file returned by the translator should first be processed with the new gti-process-google-spreadsheet.pl script:
       GS2/bin/script>perl -S gti-process-google-spreadsheet.pl ~/Desktop/core-mi-xml2spreadsheet-out.txt > <language>-submission.xml

       Then continue processing as usual
       > cat <language>-submission.xml | perl -S gti.pl submit-translations <language-code> <module-name> <username>

    -->

  <xsl:output method="text" encoding="UTF-16"/> <!-- When we save as txt from Excel, we choose UTF-16 too -->

  <xsl:template match="tmx:tmx">
    <xsl:apply-templates select="tmx:body"/>
  </xsl:template>

  <xsl:template match="tmx:body">
    <xsl:text>Source key&#09;Source text&#09;Target key&#09;Target text</xsl:text><!--column headings separated by tabs-->
    <xsl:text>&#10;</xsl:text> <!--newline-->  
    <xsl:apply-templates select="tmx:tu"/>
  </xsl:template>

  <xsl:template match="tmx:tu">
    <xsl:for-each select="tmx:tuv">
      <xsl:if test="tmx:prop[@type='source']">
	<xsl:text>source::</xsl:text>
	<xsl:value-of select="tmx:prop"/>
	<xsl:text>&#09;</xsl:text><!-- tab -->
	<xsl:variable name="tempText1"><xsl:value-of select="tmx:seg"/></xsl:variable>
	<xsl:variable name="tempText2" select='java:org.nzdl.gsdl.ApplyXSLT.replaceAll($tempText1, "&amp;#10;&#10;", "&amp;#10;")'/>
	<xsl:variable name="tempText3" select='java:org.nzdl.gsdl.ApplyXSLT.replaceAll($tempText2, "&amp;lt;", "&#60;")'/>
	<xsl:variable name="tempText4" select='java:org.nzdl.gsdl.ApplyXSLT.replaceAll($tempText3, "&amp;gt;", "&#62;")'/>
	<xsl:variable name="escapedText" select='java:org.nzdl.gsdl.ApplyXSLT.replaceAll($tempText4, "&amp;amp;", "&#38;")'/>
	<xsl:value-of select='$escapedText' disable-output-escaping="yes"/>
	<xsl:text>&#09;</xsl:text><!-- tab -->
	</xsl:if>
    </xsl:for-each>

    <xsl:for-each select="tmx:tuv">
      <xsl:if test="tmx:prop[@type='target']">
	<xsl:text>target::</xsl:text>
	<xsl:value-of select="tmx:prop"/>
	<xsl:text>&#09;</xsl:text><!-- tab -->
	<xsl:variable name="tempText1"><xsl:value-of select="tmx:seg"/></xsl:variable>
	<xsl:variable name="tempText2" select='java:org.nzdl.gsdl.ApplyXSLT.replaceAll($tempText1, "&amp;#10;&#10;", "&amp;#10;")'/>
	<xsl:variable name="tempText3" select='java:org.nzdl.gsdl.ApplyXSLT.replaceAll($tempText2, "&amp;lt;", "&#60;")'/>
	<xsl:variable name="tempText4" select='java:org.nzdl.gsdl.ApplyXSLT.replaceAll($tempText3, "&amp;gt;", "&#62;")'/>
	<xsl:variable name="escapedText" select='java:org.nzdl.gsdl.ApplyXSLT.replaceAll($tempText4, "&amp;amp;", "&#38;")'/>
	<xsl:value-of select='$escapedText' disable-output-escaping="yes"/>
	<xsl:text>&#10;</xsl:text><!-- newline -->
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

</xsl:stylesheet>
